@@ -2,10 +2,7 @@
 
 set -eu
 
-echo "Building controller-gen tool..."
-go build -o bin/controller-gen github.com/openshift/cluster-autoscaler-operator/vendor/sigs.k8s.io/controller-tools/cmd/controller-gen
-
-bin/controller-gen crd --domain openshift.io
+go run ./vendor/sigs.k8s.io/controller-tools/cmd/controller-gen crd --domain openshift.io
 
 echo "Copying generated CRDs"
 cp config/crds/autoscaling_v1_clusterautoscaler.yaml install/01_clusterautoscaler.crd.yaml
